import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { line } from 'd3-shape';
import { useEffect, useMemo } from 'react';
import { useLegend } from '../../contexts/legendContext';
import { usePlotContext } from '../../contexts/plotContext';
import { useIsSeriesVisible, useShift } from '../../hooks';
import { functionalStyle, useId, validateAxis } from '../../utils';
import { ScatterSeries } from './ScatterSeries';
export function LineSeries(props) {
    var _a;
    const [, legendDispatch] = useLegend();
    const { colorScaler } = usePlotContext();
    const id = useId(props.id, 'series');
    const { lineStyle: lineStyleFromProps = {}, displayMarkers = false, hidden, ...otherProps } = props;
    const { xAxis = 'x', yAxis = 'y', xShift: oldXShift = '0', yShift: oldYShift = '0', pointLabel, displayErrorBars, } = otherProps;
    const { xShift, yShift } = useShift({
        xAxis,
        yAxis,
        xShift: oldXShift,
        yShift: oldYShift,
    });
    const lineStyle = functionalStyle({}, lineStyleFromProps, { id });
    const isVisible = useIsSeriesVisible(id);
    useEffect(() => {
        var _a, _b, _c;
        legendDispatch({
            type: 'ADD_LEGEND_LABEL',
            payload: {
                id,
                label: otherProps.label,
                colorLine: ((_a = lineStyle === null || lineStyle === void 0 ? void 0 : lineStyle.stroke) === null || _a === void 0 ? void 0 : _a.toString()) || colorScaler(id),
                shape: {
                    color: ((_c = (_b = otherProps.markerStyle) === null || _b === void 0 ? void 0 : _b.fill) === null || _c === void 0 ? void 0 : _c.toString()) || colorScaler(id),
                    figure: otherProps.markerShape || 'circle',
                    hidden: !displayMarkers,
                },
            },
        });
        return () => legendDispatch({ type: 'REMOVE_LEGEND_LABEL', payload: { id } });
    }, [
        hidden,
        colorScaler,
        displayMarkers,
        id,
        legendDispatch,
        lineStyle === null || lineStyle === void 0 ? void 0 : lineStyle.stroke,
        otherProps.label,
        otherProps.markerShape,
        otherProps.markerStyle,
        (_a = otherProps.markerStyle) === null || _a === void 0 ? void 0 : _a.fill,
    ]);
    if (hidden)
        return null;
    const lineProps = {
        id,
        data: props.data,
        xAxis,
        yAxis,
        lineStyle,
        transform: `translate(${xShift},${yShift})`,
    };
    return (_jsxs("g", { children: [isVisible && _jsx(LineSeriesRender, { ...lineProps }), _jsx(ScatterSeries, { ...otherProps, hidden: !displayMarkers && !pointLabel && !displayErrorBars, displayMarkers: displayMarkers, id: id })] }));
}
function LineSeriesRender({ id, data, xAxis, yAxis, lineStyle, transform, }) {
    // Get scales from context
    const { axisContext, colorScaler } = usePlotContext();
    const [xScale, yScale] = validateAxis(axisContext, xAxis, yAxis);
    // calculates the path to display
    const color = colorScaler(id);
    const path = useMemo(() => {
        if (xScale === undefined || yScale === undefined) {
            return null;
        }
        // Calculate line from D3
        const lineGenerator = line()
            .x((d) => xScale(d.x))
            .y((d) => yScale(d.y));
        return lineGenerator(data);
    }, [data, xScale, yScale]);
    if (!path)
        return null;
    // default style
    const style = {
        stroke: color,
        strokeWidth: 2,
        ...lineStyle,
    };
    return _jsx("path", { transform: transform, style: style, d: path, fill: "none" });
}
//# sourceMappingURL=LineSeries.js.map