import type { CSSProperties } from 'react';
export declare type Shape = 'circle' | 'square' | 'diamond' | 'triangle' | 'cross' | 'xmark' | 'pentagon' | 'star' | 'hexagon';
export declare type HorizontalPosition = 'left' | 'right';
export declare type VerticalPosition = 'top' | 'bottom';
export declare type Position = HorizontalPosition | VerticalPosition;
export declare type Margins = Partial<Record<Position, number>>;
export declare type SeriesPointError = number | [number | null, number | null] | null;
export interface SeriesPoint {
    x: number;
    y: number;
}
export interface SeriesPointWithError extends SeriesPoint {
    xError?: SeriesPointError;
    yError?: SeriesPointError;
}
export declare type CSSFuncProps<T> = {
    [key in keyof CSSProperties]: ((point: T, index?: number, data?: T[]) => CSSProperties[key]) | CSSProperties[key];
};
export declare type ShapeFuncProps<T> = ((point: T, index?: number, data?: ReadonlyArray<T>) => Shape) | Shape;
export declare type LabelFuncProps<T> = ((point: T, index?: number, data?: ReadonlyArray<T>) => string) | string;
export interface BaseSeriesProps {
    id?: string;
    xAxis?: string;
    yAxis?: string;
    label?: string;
    hidden?: boolean;
    xShift?: ScalarValue;
    yShift?: ScalarValue;
}
export declare type ActionType<Action, Payload = void> = Payload extends void ? {
    type: Action;
} : {
    type: Action;
    payload: Payload;
};
export declare type TickLabelFormat<T = number> = (value: T) => string;
export declare type TickPosition = 'inner' | 'outer' | 'center';
export declare type ScalarValue = number | `${number}%` | `${number}`;
