"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useAxisZoom = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const Line_1 = require("../components/Annotations/Line");
const Rectangle_1 = require("../components/Annotations/Rectangle");
const plotControllerContext_1 = require("../contexts/plotController/plotControllerContext");
const useStartMoveEnd_1 = require("./useStartMoveEnd");
function useAxisZoom(options = {}) {
    const { controllerId, direction = 'horizontal', axisId = direction === 'horizontal' ? 'x' : 'y', color = 'red', rectangleStyle, lineStyle, } = options;
    const plotControls = (0, plotControllerContext_1.usePlotControls)(options);
    const startMoveEnd = (0, useStartMoveEnd_1.useStartMoveEnd)({
        controllerId,
        onEnd(_, start, end) {
            const startCoord = start.clampedCoordinates[axisId];
            const endCoord = end.clampedCoordinates[axisId];
            if (startCoord === endCoord) {
                return;
            }
            plotControls.setAxis(axisId, {
                min: Math.min(startCoord, endCoord),
                max: Math.max(startCoord, endCoord),
            });
        },
    });
    (0, plotControllerContext_1.usePlotEvents)({
        onDoubleClick({ event: { button } }) {
            if (button !== 0)
                return;
            plotControls.resetAxis(axisId);
        },
    }, options);
    if (!(startMoveEnd === null || startMoveEnd === void 0 ? void 0 : startMoveEnd.end)) {
        return { annotations: null };
    }
    const start = startMoveEnd.start.clampedCoordinates[axisId];
    const end = startMoveEnd.end.clampedCoordinates[axisId];
    const lineProps = {
        color,
        strokeWidth: '2',
        style: lineStyle,
    };
    const rectangleProps = {
        color,
        fillOpacity: 0.2,
        style: rectangleStyle,
    };
    let annotations;
    if (direction === 'horizontal') {
        annotations = ((0, jsx_runtime_1.jsxs)(jsx_runtime_1.Fragment, { children: [(0, jsx_runtime_1.jsx)(Line_1.Line, { x1: start, x2: start, y1: "0", y2: "100%", ...lineProps }), (0, jsx_runtime_1.jsx)(Rectangle_1.Rectangle, { x1: start, x2: end, y1: "0", y2: "100%", ...rectangleProps }), (0, jsx_runtime_1.jsx)(Line_1.Line, { x1: end, x2: end, y1: "0", y2: "100%", ...lineProps })] }));
    }
    else {
        annotations = ((0, jsx_runtime_1.jsxs)(jsx_runtime_1.Fragment, { children: [(0, jsx_runtime_1.jsx)(Line_1.Line, { x1: "0", x2: "100%", y1: start, y2: start, ...lineProps }), (0, jsx_runtime_1.jsx)(Rectangle_1.Rectangle, { x1: "0", x2: "100%", y1: start, y2: end, ...rectangleProps }), (0, jsx_runtime_1.jsx)(Line_1.Line, { x1: "0", x2: "100%", y1: end, y2: end, ...lineProps })] }));
    }
    return { annotations };
}
exports.useAxisZoom = useAxisZoom;
